@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-extensions-manager-ui-extension.c,v 1.6 2005/12/02 12:50:17 chpe Exp $
+ *  $Id: ephy-extensions-manager-ui-extension.c,v 1.7 2006/01/21 21:16:42 rslinckx Exp $
  */
 
 #include "config.h"
@@ -62,7 +62,7 @@ static const GtkActionEntry action_entries [] =
 {
 	{ "ExtensionsManagerUI",
 	  NULL,
-	  N_("_Extensions"),
+	  N_("_Extensions..."),
 	  NULL,
 	  N_("Load and unload extensions"),
 	  G_CALLBACK (display_cb) },
